==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/aspectframe.cc <==
// $Id: aspectframe.cc,v 1.13 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "bin.hh"

class Gtk_AspectFrame : public Gtk_Bin
{public:
	typedef Gtk_Bin Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_AspectFrame();
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_AspectFrame Gtk_AspectFrame;

const std::string Gtk_AspectFrame::TypeName(const Widget &w) const
{  return GtkPrefix()+"AspectFrame";
}

const std::string Gtk_AspectFrame::IncludeName(const Widget &w) const
{  return "gtk--/aspectframe.h";
}

Gtk_AspectFrame::Gtk_AspectFrame()
{  Writer["GtkAspectFrame"]=this;
}

//#warning this code is untested

==> glademm_2.6.0.orig.tar.gz: glademm-2.6.0/src/writers/aspectframe.cc <==
// $Id: aspectframe.cc,v 1.14 2002/05/14 08:25:44 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "bin.hh"

class Gtk_AspectFrame : public Gtk_Bin
{public:
	typedef Gtk_Bin Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_AspectFrame();
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_AspectFrame Gtk_AspectFrame;

const std::string Gtk_AspectFrame::TypeName(const Widget &w) const
{  return GtkPrefix()+"AspectFrame";
}

const std::string Gtk_AspectFrame::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"aspectframe.h";
}

Gtk_AspectFrame::Gtk_AspectFrame()
{  Writer["GtkAspectFrame"]=this;
}

//#warning this code is untested
